from bbot.modules.templates.bucket import bucket_template


class bucket_azure(bucket_template):
    watched_events = ["DNS_NAME", "STORAGE_BUCKET"]
    produced_events = ["STORAGE_BUCKET", "FINDING"]
    flags = ["active", "safe", "cloud-enum", "web-basic", "web-thorough"]
    meta = {"description": "Check for Azure storage blobs related to target"}
    options = {"permutations": False}
    options_desc = {
        "permutations": "Whether to try permutations",
    }

    cloud_helper_name = "azure"
    delimiters = ("", "-")
    base_domains = ["blob.core.windows.net"]
    # Dirbusting is required to know whether a bucket is public
    supports_open_check = False

    async def check_bucket_exists(self, bucket_name, url):
        url = url.strip("/") + f"/{bucket_name}?restype=container"
        response = await self.helpers.request(url, retries=0)
        status_code = getattr(response, "status_code", 0)
        existent_bucket = status_code != 0
        return existent_bucket, set(), bucket_name, url



from .base import ModuleTestBase


class TestSocial(ModuleTestBase):
    targets = ["http://127.0.0.1:8888"]
    modules_overrides = ["httpx", "excavate", "social"]

    async def setup_after_prep(self, module_test):
        expect_args = {"method": "GET", "uri": "/"}
        respond_args = {
            "response_data": '<html><a href="https://discord.gg/asdf"/><a href="https://github.com/blacklanternsecurity/bbot"/></html>'
        }
        module_test.set_expect_requests(expect_args=expect_args, respond_args=respond_args)

    def check(self, module_test, events):
        assert any(e.type == "SOCIAL" and e.data["platform"] == "discord" for e in events)
        assert any(
            e.type == "SOCIAL" and e.data["platform"] == "github" and e.data["profile_name"] == "blacklanternsecurity"
            for e in events
        )
